@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: AttachSettings.py 11616 2019-06-07 02:15:46Z Andy $
+# $Id: AttachSettings.py 11625 2019-06-10 07:12:00Z Andy $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,10 +12,11 @@
 # limitations under the License.
 #
 # $Author: Andy $
-# $Date: 2019-06-07 10:15:46 +0800 (週五, 07 六月 2019) $
-# $Revision: 11616 $
+# $Date: 2019-06-10 15:12:00 +0800 (週一, 10 六月 2019) $
+# $Revision: 11625 $
 
 import os
+from Iuppiter import Util
 
 def attachSettings(settingsDict):
 
@@ -50,16 +51,17 @@ def attachSettings(settingsDict):
         #=======================================================================
         THEOPHRUSTUS_STATIC_DIRS = settingsDict.get(
              'THEOPHRUSTUS_STATIC_DIRS',
-             os.path.join(CURRENT_PATH, 'static')
-             )    
+             [os.path.join(CURRENT_PATH, 'static')]
+        )    
         if settingsDict.get('STATICFILES_DIRS') == None:
-            staticDirs = []
+            STATIC_DIRS = []
         else:
-            staticDirs = list(settingsDict.get('STATICFILES_DIRS'))
-        if settingsDict.get('THEOPHRUSTUS_STATIC_DIRS') == None:
-            staticDirs.append(THEOPHRUSTUS_STATIC_DIRS)            
-        settingsDict['STATICFILES_DIRS'] = tuple(staticDirs)
-        
+            STATIC_DIRS = list(settingsDict.get('STATICFILES_DIRS'))
+            
+        #判斷 STATIC_DIRS 中是否已經存在有 THEOPHRUSTUS_STATIC_DIRS
+        UNIQUE_STATIC_DIRS = Util.extendUnique(THEOPHRUSTUS_STATIC_DIRS,
+                                                STATIC_DIRS)          
+        settingsDict['STATICFILES_DIRS'] = tuple(UNIQUE_STATIC_DIRS)
         
         #=======================================================================
         # Attach TINYMCE_DEFAULT_CONFIG.
