@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 10838 2018-03-12 10:54:45Z David $
+# $Id: admin.py 11616 2019-06-07 02:15:46Z Andy $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $
-# $Date: 2018-03-12 18:54:45 +0800 (週一, 12 三月 2018) $
-# $Revision: 10838 $
+# $Author: Andy $
+# $Date: 2019-06-07 10:15:46 +0800 (週五, 07 六月 2019) $
+# $Revision: 11616 $
 
 from django.contrib import admin
 from django.conf import settings
@@ -51,7 +51,7 @@ admin.site.register(MailingList, NewMailingListAdmin)
 
 import types
 
-from HTMLParser import HTMLParseError
+#from HTMLParser import HTMLParseError
 
 from emencia.django.newsletter.admin.newsletter import NewsletterAdmin
 from emencia.django.newsletter.mailer import Mailer
@@ -77,7 +77,7 @@ def send_mail_test(self, request, queryset):
                 )
 
                 mailer.run()
-            except HTMLParseError:
+            except Exception as e:
                 self.message_user(
                     request,
                     _('Unable send newsletter, due to errors within HTML.'))
@@ -91,5 +91,7 @@ def send_mail_test(self, request, queryset):
 
 send_mail_test.short_description = _('Send test email')
 
+# NewsletterAdmin.send_mail_test = types.MethodType(
+                                    # send_mail_test, None, NewsletterAdmin)
 NewsletterAdmin.send_mail_test = types.MethodType(
-                                    send_mail_test, None, NewsletterAdmin)
\ No newline at end of file
+                                    send_mail_test, NewsletterAdmin)
\ No newline at end of file
