@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: forms.py 10816 2018-03-05 07:24:25Z David $
+# $Id: forms.py 11616 2019-06-07 02:15:46Z Andy $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,12 +11,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $
-# $Date: 2018-03-05 15:24:25 +0800 (週一, 05 三月 2018) $
-# $Revision: 10816 $
+# $Author: Andy $
+# $Date: 2019-06-07 10:15:46 +0800 (週五, 07 六月 2019) $
+# $Revision: 11616 $
 
 from django import forms
-from django.forms.models import save_instance
+#from django.forms.models import save_instance
 from django.core.urlresolvers import reverse
 from django.utils.translation import ugettext as _
 
