@@ -18,11 +18,10 @@ class Migration(migrations.Migration):
 
     dependencies = [
         ('newsletter_extension', '0004_auto_20171219_1532'),
-        ('cloud', '0002_errormessage')
     ]
 
     operations = [
-        migrations.RunPython(moveErrorMessages),
+        #migrations.RunPython(moveErrorMessages),
         migrations.RemoveField(
             model_name='errormessage',
             name='contact',
