@@ -15,7 +15,7 @@
 # $Date: 2013-05-16 06:52:28 +0000 (週四, 16 五月 2013) $
 # $Revision: 9166 $
 
-from django.conf.urls import url, include, patterns
+from django.conf.urls import url, include
 # Required import for 404 handle.
 from django.conf.urls import handler404
 # Required import for 500 handle.
@@ -26,7 +26,7 @@ admin.autodiscover()
 
 import views
 
-urlpatterns = patterns('',
+urlpatterns = [
     # Homepage.
     (r'^$', views.getIndex),
 
@@ -40,7 +40,7 @@ urlpatterns = patterns('',
 
     # Tinymic editor.
     (r'^tinymce/', include('tinymce.urls')),
-)
+]
 
 import settings
 from Iuno import Patch
